# ARPACK++ v2.3.0 9/1/2016
# c++ interface to ARPACK code.
# This file contains some definitions used to compile arpack++ examples
# with the c++ compiler under FreeBSD.


# Defining the machine.

PLAT         = `uname -s`

# Defining the compiler.

CPP          = $(CXX)

# Defining ARPACK++ directories.
# ARPACKPP_INC is the directory that contains all arpack++ header files.
# SUPERLU_DIR and UMFPACK_DIR must be set to ARPACKPP_INC.

ARPACK_INC   = /usr/local/include/arpack
ARPACKPP_INC   = /usr/local/include/ARPACK++
ARPACKPP_DIR = /usr/local/share/
SUPERLU_DIR  = /usr/local/include/superlu
UMFPACK_DIR  = /usr/local/include/suitesparse

# Defining ARPACK, LAPACK, UMFPACK, SUPERLU, BLAS and FORTRAN libraries.
# See the arpack++ manual or the README file for directions on how to 
# obtain arpack, umfpack and SuperLU packages. 
# UMFPACK_LIB and SUPERLU_LIB must be declared only if umfpack and superlu 
# are going to be used. Some BLAS and LAPACK fortran routines are 
# distributed along with arpack fortran code, but the user should verify 
# if optimized versions of these libraries are available before installing 
# arpack. The fortran libraries described below are those required to link
# fortran and c++ code using gnu g++ and f77 compiler under linux.
# Other libraries should be defined if the user intends to compile
# arpack++ on another environment.

ARPACK_LIB   = -larpack
LAPACK_LIB   = -llapack
SUPERLU_LIB  = -lsuperlu
BLAS_LIB     = -lblas
FORTRAN_LIBS = -lgfortran

# SuiteSparse contains the UMFPACK and CHOLMOD code. To link examples against 
# these, set the SUITESPARSE_DIR to point to your installation:
SUITESPARSE_DIR = /usr/local/include/suitesparse

UMFPACK_LIB  = -lumfpack  \
 -lcholmod \
 -lcolamd \
 -lccolamd \
 -lmetis  \
 -lcamd \
 -lamd \
 -lsuitesparseconfig 
 
CHOLMOD_LIB  = -lcholmod \
 -lcolamd \
 -lccolamd \
 -lmetis  \
 -lcamd \
 -lamd

# For cholmod need additional headers:
CHOLMOD_INC  = -I$(SUITESPARSE_DIR)


# Defining g++ flags and directories.

# CPP_WARNINGS = -fpermissive 
#CPP_WARNINGS = -Wall -ansi -pedantic-errors
CPP_WARNINGS = -Wno-deprecated
CPP_DEBUG    = -g
CPP_OPTIM    = -O
CPP_LIBS     = -lm
CPP_INC      = 

CPP_FLAGS    = $(CXXFLAGS) $(CPP_WARNINGS) -D$(PLAT) -I$(ARPACKPP_INC) $(FCFLAGS)

# Putting all libraries together.

ALL_LIBS     = $(LDFLAGS) $(ARPACK_LIB) $(LAPACK_LIB) $(BLAS_LIB) $(FORTRAN_LIBS) $(CPP_LIBS)

# defining paths.

vpath %.h  $(ARPACK_INC)

